@@ -48,8 +48,8 @@ def _copy_log_file(host, port, username, ssh_key_file, remote_log_dir, cluster_n
     remote_log_filename = os.path.join(remote_log_dir, 'tiflash.log')
     local_log_filename = os.path.join(FLASHPROF_CLUSTER_DIR, cluster_name, 'log', '{}.tiflash.log'.format(host))
     # remote_log_filename = '/mnt/pingcap/tiflash_mpp_profiler/log/172.16.5.59.tiflash.log'
-    command = r'grep -P "\[\"mpp_task_tracing:<query:\d+,task:\d+>" {}'.format(remote_log_filename) if tso is None \
-        else r'grep -P "\[\"mpp_task_tracing:<query:{},task:\d+>" {}'.format(tso, remote_log_filename)
+    command = r'grep -P "\[\"mpp_task_tracing:[a-zA-Z]*<query:\d+,task:\d+>" {}'.format(remote_log_filename) if tso is None \
+        else r'grep -P "\[\"mpp_task_tracing:[a-zA-Z]*<query:\d+,task:\d+>" {}'.format(tso, remote_log_filename)
     logging.debug('executing ssh command: {}'.format(command))
     stdin, stdout, stderr = ssh.exec_command(command)
     logging.info('grep & scp {}@{}:{}/{} {}'.format(username, host, port, remote_log_filename, local_log_filename))
@@ -72,7 +72,7 @@ def _parse_one_log_to_file(log_file, task_dag_json_dir):
     ret = []
     with open(log_file, 'r') as fd:
         for line in fd:
-            match = re.search(r'\["mpp_task_tracing:<query:\d+,task:\d+> (\{.+\})', line)
+            match = re.search(r'\["mpp_task_tracing:[a-zA-Z]*<query:\d+,task:\d+> (\{.+\})', line)
             if match is None:
                 continue
             json_str = match.group(1).replace('\\', '')
@@ -175,23 +175,23 @@ def _render_files(json_path, out_dir, type, format):
         for task_id, tasks in tasks_map.items():
             if len(tasks) == 1:  # only INITIALIZING
                 if tasks[0]['status'] != 'INITIALIZING':
-                    raise ValueError(
-                        'expect the only task has status INITIALIZING, tso [{}], task_id [{}]'.format(query_tso, task_id))
+                    logging.error('expect the only task has status INITIALIZING, tso [{}], task_id [{}]'.format(query_tso, task_id))
+                    continue
                 status_pruned[query_tso].append(tasks[0])
             elif len(tasks) == 2:  # has INITIALIZING and FINISHED/CANCELLED
                 if tasks[0]['status'] == tasks[1]['status'] == 'INITIALIZING':
-                    raise ValueError(
-                        '2 tasks must not all have INITIALIZING status, tso [{}], task_id [{}]'.format(query_tso, task_id))
-                if tasks[0]['status'] != 'INITIALIZING' and tasks[0]['status'] != 'INITIALIZING':
-                    raise ValueError(
-                        'at least 1 task must have INITIALIZING status, tso [{}], task_id [{}]'.format(query_tso, task_id))
+                    logging.error('2 tasks must not all have INITIALIZING status, tso [{}], task_id [{}]'.format(query_tso, task_id))
+                    continue
+                if tasks[0]['status'] != 'INITIALIZING' and tasks[1]['status'] != 'INITIALIZING':
+                    logging.error('at least 1 task must have INITIALIZING status, tso [{}], task_id [{}]'.format(query_tso, task_id))
+                    continue
                 _task = tasks[0]
                 if _task['status'] == 'INITIALIZING':
                     _task = tasks[1]
                 status_pruned[query_tso].append(_task)
             else:
-                raise ValueError(
-                    'expect only 1 or 2 tasks with status, got [{}], tso [{}], task_id [{}]'.format(len(tasks), query_tso, task_id))
+                logging.error('expect only 1 or 2 tasks with status, got [{}], tso [{}], task_id [{}]'.format(len(tasks), query_tso, task_id))
+                continue
 
     # NOTE: we can parallelize this and utilize all the cpu cores to render
     for query_tso, data in status_pruned.items():
